@@ -26,7 +26,7 @@
 int main(int argc, char** argv)
 {
     // About Granatier
-    KAboutData about("granatier", 0, ki18n("Granatier"), "1.0.0",
+    KAboutData about("granatier", 0, ki18n("Granatier"), "1.1.0",
         ki18n("Granatier is a Bomberman Clone!"),
         KAboutData::License_GPL, ki18n("Copyright (c) 2009 The Granatier Team!"));
     about.addAuthor(ki18n("Mathias Kraus"), ki18n("Maintainer"), "k.hias@gmx.de", 0);
@@ -41,9 +41,6 @@ int main(int argc, char** argv)
     KApplication app;
     // Insert libkdegames catalog, for translation of libkdegames messages
     KGlobal::locale()->insertCatalog( QLatin1String( "libkdegames" ));
-    #ifndef GRANATIER_USE_OPENAL
-    qWarning() << "Using Phonon for sound. OpenAL provides a better sound experience. Consider building Granatier with OpenAL.";
-    #endif
     // Create the main window
     MainWindow* window = new MainWindow();
     // Show the main window
