@@ -2,11 +2,11 @@
 
 """
 Authors of original libkmahjongg in C++:
-    Copyright (C) 1997 Mathias Mueller   <in5y158@public.uni-hamburg.de>
-    Copyright (C) 2006 Mauricio Piacentini  <mauricio@tabuleiro.com>
+    Copyright (C) 1997 Mathias Mueller <in5y158@public.uni-hamburg.de>
+    Copyright (C) 2006 Mauricio Piacentini <mauricio@tabuleiro.com>
 
 this adapted python code:
-    Copyright (C) 2008,2009,2010 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+    Copyright (C) 2008-2011 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
     kajongg is free software you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,12 +20,12 @@ this adapted python code:
 
     You should have received a copy of the GNU General Public License
     along with this program if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
 from PyQt4.QtCore import QString, QVariant, QSizeF
 from PyQt4.QtSvg import QSvgRenderer
-from PyKDE4.kdecore import KStandardDirs, KGlobal, KConfig, KConfigGroup
+from kde import KGlobal, KStandardDirs, KConfig, KConfigGroup
 from util import logWarning, logException, m18n
 import common
 from common import LIGHTSOURCES, InternalParameters
@@ -62,8 +62,14 @@ class Tileset(object):
         Tileset.defineCatalog()
         tilesAvailableQ = KGlobal.dirs().findAllResources(
             "kmahjonggtileset", "*.desktop", KStandardDirs.Recursive)
-        # now we have a list of full paths. Use the base name minus .desktop:
-        tilesets = [str(x).rsplit('/')[-1].split('.')[0] for x in tilesAvailableQ ]
+        # now we have a list of full paths. Use the base name minus .desktop
+        # put result into a set, avoiding duplicates
+        tilesets = set(str(x).rsplit('/')[-1].split('.')[0] for x in tilesAvailableQ)
+        if 'default' in tilesets:
+            # we want default to be first in list
+            sortedTilesets = ['default']
+            sortedTilesets.extend(tilesets-set(['default']))
+            tilesets = sortedTilesets
         for dontWant in ['alphabet', 'egypt']:
             if dontWant in tilesets:
                 tilesets.remove(dontWant)
@@ -81,8 +87,9 @@ class Tileset(object):
         if self.path.isEmpty():
             self.path = locateTileset('default.desktop')
             if self.path.isEmpty():
+                directories = '\n\n' +'\n'.join(str(x) for x in KGlobal.dirs().resourceDirs("kmahjonggtileset"))
                 logException(TileException(m18n( \
-                'cannot find any tileset, is libkmahjongg installed?')))
+                'cannot find any tileset in the following directories, is libkmahjongg installed?') + directories))
             else:
                 logWarning(m18n('cannot find tileset %1, using default', desktopFileName))
                 self.desktopFileName = 'default'
@@ -92,17 +99,17 @@ class Tileset(object):
         tileconfig = KConfig(self.path, KConfig.SimpleConfig)
         group = KConfigGroup(tileconfig.group("KMahjonggTileset"))
 
-        self.name = group.readEntry("Name",  "unknown tileset").toString() # Returns translated data
-        self.author = group.readEntry("Author",  "unknown author").toString()
-        self.description = group.readEntry("Description",  "no description available").toString()
-        self.authorEmail = group.readEntry("AuthorEmail",  "no E-Mail address available").toString()
+        self.name = group.readEntry("Name", "unknown tileset").toString() # Returns translated data
+        self.author = group.readEntry("Author", "unknown author").toString()
+        self.description = group.readEntry("Description", "no description available").toString()
+        self.authorEmail = group.readEntry("AuthorEmail", "no E-Mail address available").toString()
 
         #Version control
         tileversion, entryOK = group.readEntry("VersionFormat", QVariant(0)).toInt()
         #Format is increased when we have incompatible changes, meaning that
         # older clients are not able to use the remaining information safely
         if not entryOK or tileversion > TILESETVERSIONFORMAT:
-            logException(TileException('tileversion file / program: %d/%d' %  \
+            logException(TileException('tileversion file / program: %d/%d' % \
                 (tileversion, TILESETVERSIONFORMAT)))
 
         graphName = QString(group.readEntry("FileName"))
