@@ -41,6 +41,8 @@
 
 KLinesMainWindow::KLinesMainWindow()
 {
+    KLinesRenderer::Init();
+
     mwidget = new MainWidget(this);
     setCentralWidget( mwidget );
 
@@ -58,6 +60,7 @@ KLinesMainWindow::KLinesMainWindow()
 
 KLinesMainWindow::~KLinesMainWindow()
 {
+  KLinesRenderer::UnInit();
 }
 
 void KLinesMainWindow::setupActions()
@@ -176,6 +179,7 @@ void KLinesMainWindow::configureSettings()
         return;
     KConfigDialog *dialog = new KConfigDialog( this, QLatin1String( "settings" ), Prefs::self() );
     dialog->addPage( new KGameThemeSelector( dialog, Prefs::self(), KGameThemeSelector::NewStuffDisableDownload  ), i18n( "Theme" ), QLatin1String( "games-config-theme" ));
+	dialog->setFaceType(KConfigDialog::Plain); //only one page -> no page selection necessary
     connect( dialog, SIGNAL( settingsChanged(const QString&) ), this, SLOT( loadSettings() ) );
     dialog->setHelp(QString(),QLatin1String( "klines" ));
     dialog->show();
@@ -183,7 +187,7 @@ void KLinesMainWindow::configureSettings()
 
 void KLinesMainWindow::loadSettings()
 {
-    if ( !KLinesRenderer::self()->loadTheme() )
+    if ( !KLinesRenderer::loadTheme() )
     {
         KMessageBox::error( this,  i18n( "Failed to load \"%1\" theme. Please check your installation.", Prefs::theme() ) );
         return;
