@@ -185,7 +185,7 @@ void GypsySolver::undo_move(MOVE *m)
             Wp[from]++;
             *Wp[from] = card;
             Wlen[from]++;
-            *Wp[to]--;
+            Wp[to]--;
         }
         Wlen[to] -= m->card_index + 1;
         hashpile(to);
@@ -368,25 +368,28 @@ int GypsySolver::get_possible_moves(int *a, int *numout)
                     mp->pri = params[2];
                 else
                     mp->pri = params[3];
-                card_t card2 = W[i][Wlen[i]-2-l];
-                if ( Wlen[i] >= l+2 && RANK( card ) == RANK( card2 ) - 1 &&
-                     COLOR( card ) != COLOR( card2 ) && !DOWN( card2 ) )
-                {
-                    int o = SUIT(card2);
-                    for ( int off = 0; off < 2; ++off )
-                    {
-                        bool empty = !Wlen[o*2+off+outs];
-                        if ((empty && (RANK(card2) == PS_ACE)) ||
-                            (!empty && (RANK(card2) == RANK( *Wp[outs+o*2+off] ) + 1 ) ) )
-                        {
-                            o = -1;
-                            break;
-                        }
-                    }
-                    if ( o > -1 )
-                        continue;
-                    mp->pri = ( int )qMin( qreal( 127. ), params[1] + qreal( l ) * params[5] / 10 );
-                }
+		if (Wlen[i] >= 2+l) {
+		  card_t card2 = W[i][Wlen[i]-2-l];
+		  if ( Wlen[i] >= l+2 && RANK( card ) == RANK( card2 ) - 1 &&
+		       COLOR( card ) != COLOR( card2 ) && !DOWN( card2 ) )
+		    {
+		      int o = SUIT(card2);
+		      for ( int off = 0; off < 2; ++off )
+			{
+			  bool empty = !Wlen[o*2+off+outs];
+			  if ((empty && (RANK(card2) == PS_ACE)) ||
+			      (!empty && (RANK(card2) == RANK( *Wp[outs+o*2+off] ) + 1 ) ) )
+			    {
+			      o = -1;
+			      break;
+			    }
+			}
+		      if ( o > -1 )
+			mp->pri = -117;
+		      else
+			mp->pri = ( int )qMin( qreal( 127. ), params[1] + qreal( l ) * params[5] / 10 );
+		    }
+		}
                 n++;
                 mp++;
             }
@@ -409,11 +412,6 @@ int GypsySolver::get_possible_moves(int *a, int *numout)
     return n;
 }
 
-void GypsySolver::unpack_cluster( int )
-{
-
-}
-
 bool GypsySolver::isWon()
 {
     // maybe won?
@@ -485,7 +483,7 @@ void GypsySolver::translate_layout()
     }
 
     for (int i = 0; i < 8; ++i) {
-        KCard *c = deal->target[i]->top();
+        KCard *c = deal->target[i]->topCard();
         if (c) {
             int suit = translateSuit( c->suit() ) >> 4;
             int target = outs + suit*2;
@@ -498,11 +496,6 @@ void GypsySolver::translate_layout()
     }
 }
 
-int GypsySolver::getClusterNumber()
-{
-    return 1;
-}
-
 void GypsySolver::print_layout()
 {
     int i, w, o;
@@ -542,7 +535,7 @@ MoveHint GypsySolver::translateMove( const MOVE &m )
         PatPile *target = 0;
         PatPile *empty = 0;
         for (int i = 0; i < 8; ++i) {
-            KCard *c = deal->target[i]->top();
+            KCard *c = deal->target[i]->topCard();
             if (c) {
                 if ( c->suit() == card->suit() && c->rank() == card->rank() - 1)
                 {
